#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_TRUE_FALSE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_TRUE_FALSE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/true_false.hpp>

#endif
